"""Constant values for this package."""

# Import built-in modules
import logging
import sys

# Using Python-3 or Python-2.
PY3 = False
PY2 = False
if sys.version_info[0] == 3:
    PY3 = True
if sys.version_info[0] == 2:
    PY2 = True

# Pattern to use for extraction of file name, file sequence number and file
# extension.
# https://regex101.com/r/62aRDK/1
FILE_SEQUENCE_PATTERN = r"(?P<base>.*[\.|_])(?P<counter>\d+|%\d+d|#+)(?P<ext>\.[a-z]+)"

# Name of this package.
PACKAGE_NAME = "smartMedia"

# Format to use for logging.
LOGGING_FORMAT = "%(name)s [%(levelname)s]: %(message)s"

# Logging levels to use throughout this package.
LOGGING_LEVELS = {
    "debug": logging.DEBUG,
    "info": logging.INFO,
    "warning": logging.WARNING,
    "error": logging.ERROR
}

# All file extensions for footage that are ingestable into smartMedia.
INGESTABLE_EXTENSIONS_FOOTAGE = (
    # All allowed image extensions.
    ".exr",
    ".tif",
    ".tiff",
    ".jpg",
    ".jpeg",
    ".mov",
    ".png",
    ".dpx",
    ".cin",
    ".hdr",
    ".targa",
    ".tga",
    # All allowed video extensions.
    ".mov",
    ".mp4",
)

# File extensions of video files.
VIDEO_EXTENSIONS = (
    ".mov",
    ".mp4",
    ".r3d",
)

FILE_SEQUENCE_EXTENSIONS = list(
    set(INGESTABLE_EXTENSIONS_FOOTAGE) - set(VIDEO_EXTENSIONS)
)

# The number of spaces to use when indenting json fields.
JSON_INDENT = 4

# The naming pattern of a job log file.
# Examples:
# 1586894392_hello.txt
# 1586894392_render_v004.txt
# 1586894392_der_001_001_comp_v001_sij.txt
# https://regex101.com/r/kVnmrU/1
JOB_LOG_PATTERN = r"(?P<timestamp>\d+)_(?P<name>.*)\.txt"

# Name of the environment variable to set to search for preset folders.
# Separate multiple paths by os.pathsep.
PRESETS_PATH = "CRAGL_SMARTMEDIA_PRESET_PATHS"

# Width of all job thumbnails when ingesting media. The height is set
# accordingly in aspect to this width.
THUMBNAIL_WIDTH = 540

# Regex to allow all numbers.
# https://regex101.com/r/Sticfl/1
PATTERN_ALL_NUMBERS = r"^[0-9]*$"

# Regex to allow all numbers and floats.
# https://regex101.com/r/5UsoM7/2
PATTERN_FLOATS = r"^[0-9]*\.?[0-9]+$"

# Concatenate a task's settings keys with this sub string. This gets used
# In the 'Edit task details visibility' view as well as in the settings that
# get saved for the visibility of a certain details widget.
# ! Don't change this value again because it gets saved in the settings .json
# file. When updating this value, the old value will still persist and the
# value will be shown in the UI. That's not too bad, but can be avoided since
# the resulting buttons will be useless and won't do anything anymore.
TASK_WIDGET_DETAILS_SETTINGS_CONCATENATOR = " | "
