"""Ask to generate a new template on the fly or use default template."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc import helper


class PageGenerateTemplate(QtWidgets.QWizardPage):
    """Ask to generate a new template on the fly or use default template."""

    def __init__(self, page_index, count_all_pages):
        """Initialize the PageInto instance.

        Args:
            page_index (int): The index of the current page shown.
            count_all_pages (int): The number of all pages in the wizard.

        """
        super(PageGenerateTemplate, self).__init__()

        self.page_index = page_index
        self.count_all_pages = count_all_pages

        self.create_widgets()
        self.create_layouts()
        self.create_signals()
        self.register_fields()

        self.setButtonText(
            QtWidgets.QWizard.FinishButton,
            "Finish and create template"
        )

        helper.set_tooltips(self, "wizard_page_generate_template")

    def create_widgets(self):
        """Create the intro page."""
        self.label_title = QtWidgets.QLabel(
            "Generate template.nk (Page: {}/{})".format(
                self.page_index, self.count_all_pages)
        )
        self.label_title.setObjectName("page_title")

        self.label_page_description = QtWidgets.QLabel(
            "Generate a template.nk file on the fly or use the default "
            "template for the preset."
        )
        self.label_page_description.setWordWrap(True)

        self.label_template = QtWidgets.QLabel("Use template")
        self.combo_template = QtWidgets.QComboBox()
        helper.fix_combo_solid_bg(self.combo_template)
        self.combo_template.addItems([
            "Generate template",
            "Use default template"
        ])
        helper.fix_combo_menu_width(self.combo_template)
        self.input_generate_template_mapper = QtWidgets.QLineEdit()
        self.input_generate_template_mapper.setVisible(False)
        self.update_mapper()

    def create_layouts(self):
        """Create layouts."""
        self.layout_main = QtWidgets.QVBoxLayout()
        self.layout_main.addWidget(self.label_title)
        self.layout_main.addWidget(self.label_page_description)

        self.layout_generate_template = QtWidgets.QHBoxLayout()
        self.layout_generate_template.addWidget(self.label_template)
        self.layout_generate_template.addWidget(self.combo_template)
        self.layout_generate_template.addStretch()

        self.layout_main.addLayout(self.layout_generate_template)
        self.layout_main.addWidget(self.input_generate_template_mapper)

        self.setLayout(self.layout_main)

    def create_signals(self):
        """Create signals."""
        self.combo_template.currentIndexChanged.connect(
            lambda: self.update_mapper()
        )

    def update_mapper(self):
        """Update the mapper with the selected user choice."""
        self.input_generate_template_mapper.setText(
            self.combo_template.currentText()
        )

    def register_fields(self):
        """Register fields."""
        self.registerField(
            "generate_template",
            self.input_generate_template_mapper
        )