"""Functionality that requires the nuke module."""

# Import built-in modules
import os

# Import third-party modules
import nuke
import nukescripts

# Import local modules
from smartMedia import paths


def insert_node(name_or_path):
    """Insert node with given name or from full path.

    Args:
        name (str): The name of the node to insert into the DAG without file
            extension.

    Returns:
        nuke.Node or :obj:`list` of :obj:`nuke.Node`: The node or the nodes
            that were pasted into the DAG.

    """
    nukescripts.clear_selection_recursive()

    if os.path.isfile(name_or_path):
        path = name_or_path
    else:
        path = os.path.join(
            paths.get_nodes_directory(),
            "{}.nk".format(name_or_path)
        )
    nuke.nodePaste(path)

    if len(nuke.selectedNodes()) == 1:
        return nuke.selectedNode()

    return nuke.selectedNodes()


def get_selected_nodes_media():
    """Get the media for all selected nodes.

    Returns:
        :obj:`list` of :obj:`str`: Sequence of absolute paths of selected nodes
            media.

    """
    paths = []

    for node in nuke.selectedNodes():
        file_knob = node.knob("file")
        if not file_knob or not file_knob.value():
            continue

        path = file_knob.evaluate()
        if not os.path.isfile(path):
            nuke.message(
                "Cannot ingest the following path as it does not exist: "
                "\n\n{}".format(path)
            )
            continue

        paths.append(path)

    return list(set(paths))
