"""Copy the media paths of all selected media to the clipboard."""

# Import third-party modules
try:
    from PySide import QtGui
except ImportError:
    from PySide2 import QtGui

# Import local modules
from smartMedia.media_commands.base_media_command import BaseMediaCommand


class CopyMediaPathsToClipboard(BaseMediaCommand):
    """Copy the media paths of all selected media to the clipboard."""

    def label(self):
        """Return the label to use in the UI for this command.

        Returns:
            str: The label to use for the command in the UI.

        """
        return "Copy media paths to clipboard"

    def process(self, media):
        """Copy the media paths of all selected media to the clipboard.

        Args:
            media (:obj:`list` of :obj:`smartMedia.media.Media`):
                Sequence of selected Media instances. Will copy all selected
                media paths to the clipboard.

        """
        paths = [element.path for element in media]
        paths = "\n".join(paths)

        clipboard = QtGui.QClipboard()
        clipboard.setText(paths)
