"""Provide a checkbox to enable/disable a setting."""

# Import third-party modules
try:
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc.details_widgets.base import Base


class Checkbox(Base):
    """Provide a checkbox to enable/disable a setting."""

    def create_widgets(self):
        """Create widgets."""
        super(Checkbox, self).create_widgets()

        self.label = QtWidgets.QLabel(self.label_text)
        self.label.setMinimumWidth(120)
        self.check = QtWidgets.QCheckBox()
        self.check.setChecked(bool(self.preset.data.get(self.key)))

    def create_layouts(self):
        """Create layouts."""
        super(Checkbox, self).create_layouts()

        self.layout.addWidget(self.label)
        self.layout.addWidget(self.check)
        self.layout.addStretch()

    def create_signals(self):
        """Create signals."""
        super(Checkbox, self).create_signals()

        self.check.stateChanged.connect(lambda: self.update())

    def update(self):
        """Update the preset and thus the task's data.json"""
        self.preset[self.key] = self.check.isChecked()
        self.preset.save()
