"""Provide a single line input to enter text values."""

# Import third-party modules
try:
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc.details_widgets.base import Base
from smartMedia.mvc import helper


class LineInput(Base):
    """Provide a single line input to enter text values."""

    def create_widgets(self):
        """Create widgets."""
        super(LineInput, self).create_widgets()

        self.label = QtWidgets.QLabel(self.label_text)
        self.label.setMinimumWidth(120)
        self.input = QtWidgets.QLineEdit()
        self.input.setText(self.preset.data.get(self.key, ""))
        helper.fix_no_outline(self.input)

    def create_layouts(self):
        """Create layouts."""
        super(LineInput, self).create_layouts()

        self.layout.addWidget(self.label)
        self.layout.addWidget(self.input)

    def create_signals(self):
        """Create signals."""
        super(LineInput, self).create_signals()

        self.input.textChanged.connect(lambda: self.update())

    def update(self):
        """Update the preset and thus the task's data.json"""
        self.preset[self.key] = self.input.text()
        self.preset.save()
