"""Provide a SpinBox to update a number with up and down buttons."""

# Import third-party modules
try:
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc.details_widgets.base import Base


class Spinbox(Base):
    """Provide a SpinBox to update a number with up and down buttons."""

    def create_widgets(self):
        """Create widgets."""
        super(Spinbox, self).create_widgets()

        self.label = QtWidgets.QLabel(self.key.replace("_", " "))
        self.label.setMinimumWidth(120)
        self.spin = QtWidgets.QSpinBox()
        self.spin.setMinimum(-9999999)
        self.spin.setMaximum(9999999)
        self.spin.setValue(self.preset.data.get(self.key, 1))
        self.spin.setValue(self.preset.data.get(self.key, 1))
        self.spin.setMinimumWidth(100)

    def create_layouts(self):
        """Create layouts."""
        super(Spinbox, self).create_layouts()

        self.layout.addWidget(self.label)
        self.layout.addWidget(self.spin)
        self.layout.addStretch()

    def create_signals(self):
        """Create signals."""
        super(Spinbox, self).create_signals()

        self.spin.valueChanged.connect(lambda: self.update())

    def update(self):
        """Update the preset and thus the task's data.json"""
        self.preset[self.key] = self.spin.value()
        self.preset.save()
