"""The intro page to show in the beginning of the preset creation."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc.dialogs.preset_wizard import _ICONS


class PageIntro(QtWidgets.QWizardPage):
    """The intro page to show in the beginning of the preset creation."""

    def __init__(self, page_index, count_all_pages):
        """Initialize the PageInto instance.

        Args:
            page_index (int): The index of the current page shown.
            count_all_pages (int): The number of all pages in the wizard.

        """
        super(PageIntro, self).__init__()

        self.page_index = page_index
        self.count_all_pages = count_all_pages

        self.create_widgets()
        self.create_layouts()

    def create_widgets(self):
        """Create the intro page."""
        self.label = QtWidgets.QLabel()
        self.pixmap = QtGui.QPixmap(_ICONS["logo_dark"])
        self.pixmap = self.pixmap.scaledToWidth(256, QtCore.Qt.SmoothTransformation)
        self.label.setPixmap(self.pixmap)

        self.label_title = QtWidgets.QLabel(
            "Create a new preset (Page: {}/{})".format(
                self.page_index, self.count_all_pages)
            )
        self.label_title.setObjectName("page_title")

        self.label_page_description = QtWidgets.QLabel(
            "This wizard will guide you through all steps to create a new "
            "preset. Depending on your needs, this will either create "
            "everything you need or you might need to further adjust the "
            "generated preset and template.nk file. Make sure to go through "
            "all sections. Note that you can always update any value at a "
            "later stage."
        )
        self.label_page_description.setWordWrap(True)

    def create_layouts(self):
        """Create layouts."""
        self.layout_main = QtWidgets.QVBoxLayout()
        self.layout_main.addWidget(self.label_title)
        self.layout_main.addWidget(self.label_page_description)
        self.layout_main.addWidget(self.label)

        self.setLayout(self.layout_main)
