"""Provide two line inputs to update text values for two settings."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc.details_widgets.base import Base
from smartMedia.mvc import helper


class LineInputDouble(Base):
    """Provide two line inputs to update text values for two settings."""

    def create_widgets(self):
        """Create widgets."""
        super(LineInputDouble, self).create_widgets()

        self.label_0 = QtWidgets.QLabel(self.keys[0].replace("_", " "))
        self.label_0.setMinimumWidth(120)

        self.input_0 = QtWidgets.QLineEdit()
        self.input_0.setText(self.preset.data.get(self.keys[0], ""))
        helper.fix_no_outline(self.input_0)

        self.label_1 = QtWidgets.QLabel(self.keys[1].replace("_", " "))

        self.input_1 = QtWidgets.QLineEdit()
        self.input_1.setText(self.preset.data.get(self.keys[1], ""))
        helper.fix_no_outline(self.input_1)

    def create_layouts(self):
        """Create layouts."""
        super(LineInputDouble, self).create_layouts()

        self.layout.addWidget(self.label_0)
        self.layout.addWidget(self.input_0)
        self.layout.addWidget(self.label_1)
        self.layout.addWidget(self.input_1)

    def create_signals(self):
        """Create signals."""
        super(LineInputDouble, self).create_signals()

        self.input_0.textChanged.connect(lambda: self.update())
        self.input_1.textChanged.connect(lambda: self.update())

    def update(self):
        """Update the preset and thus the task's data.json"""
        self.preset[self.keys[0]] = self.input_0.text()
        self.preset[self.keys[1]] = self.input_1.text()
        self.preset.save()
