"""Provide two SpinBoxes to update two numbers with up and down buttons."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartMedia.mvc.details_widgets.base import Base

class SpinboxRange(Base):
    """Provide two SpinBoxes to update two numbers with up and down buttons."""

    def create_widgets(self):
        """Create widgets."""
        super(SpinboxRange, self).create_widgets()

        self.label_0 = QtWidgets.QLabel(self.label_text)
        self.label_1 = QtWidgets.QLabel(" - ")

        self.label_0.setMinimumWidth(120)

        self.spin_0 = QtWidgets.QSpinBox()
        self.spin_1 = QtWidgets.QSpinBox()

        index = 0
        for widget in (self.spin_0, self.spin_1):
            widget.setMinimum(-9999999)
            widget.setMaximum(9999999)
            widget.setValue(self.preset.data.get(self.keys[index]))
            widget.setMinimumWidth(100)
            index += 1

    def create_layouts(self):
        """Create layouts."""
        super(SpinboxRange, self).create_layouts()

        self.layout.addWidget(self.label_0)
        self.layout.addWidget(self.spin_0)

        self.layout.addWidget(self.label_1)
        self.layout.addWidget(self.spin_1)

        self.layout.addStretch()

    def create_signals(self):
        """Create signals."""
        super(SpinboxRange, self).create_signals()

        self.spin_0.valueChanged.connect(lambda: self.update())
        self.spin_1.valueChanged.connect(lambda: self.update())

    def update(self):
        """Update the preset and thus the task's data.json"""
        self.preset[self.keys[0]] = self.spin_0.value()
        self.preset[self.keys[1]] = self.spin_1.value()
        self.preset.save()
