"""Execute custom code after the task has finished rendering.

Any code in the main function of this module will be executed right after
the task has finished rendering.

Each post_render.py should have at least one function called `main`. This is
the entry point for logic injection. You can build any amount of additional
functions or calls to other modules or python packages (internal or external)
around this to have absolute control over a task and do whatever you want
and need. The main function contains two arguments - the incoming data key
value pairs of your task and a logger that you can use for logging purposes.
Logs appear in the job log.

"""

# Import built-in modules
import os
import shutil


def main(data, logger):
    """This is the main entry point for post render code injections.

    Args:
        data (dict): This is the key-value pairs of the task which can be used
            to make some last minute changes before rendering the task.
        logger (logging.Logger): The logger to use for logging to std out.

    """
    logger.info(
        "Hello, I am executing custom code before opening the "
        "task's template.nk file."
    )

    # TODO Add any code here to execute before rendering.

    # Let's move the render output to somewhere else.
    source = os.path.dirname(data["target_path"])
    dest = os.path.join(
        os.path.expanduser("~"),
        "cragl",
        "smartMedia",
        "test_dev"
    )

    if os.path.isfile(dest):
        os.remove(dest)

    logger.info("Copying from %s to %s", source, dest)
    shutil.copytree(source, dest)

    logger.info(
        "I am done executing custom code before opening the task's "
        "template.nk file."
    )
