"""LineInputDouble with customizable colorspace auto completes.

This widget acts like the LineInputDouble but offers customizable auto
completes that get read from a specific file. Clicking a button on that widget
opens the text file to update the auto complete list.
"""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartMedia import paths
from smartMedia.colorspace import colorspaces
from smartMedia.mvc import helper
from smartMedia.mvc.details_widgets.line_input_double import LineInputDouble


class LineInputDoubleColorspaces(LineInputDouble):
    """LineInputDouble with customizable colorspace auto completes."""

    def create_widgets(self):
        """Create widgets."""
        super(LineInputDoubleColorspaces, self).create_widgets()

        user_colorspaces = colorspaces.load_colorspaces()

        self.completer = QtWidgets.QCompleter(user_colorspaces, self)
        self.completer.setCaseSensitivity(QtCore.Qt.CaseInsensitive)

        self.completer.popup().setStyleSheet(
            """
            background-color: #232323;
            color: #999999;
            font-size: 14pt;
            """
        )

        self.input_0.setCompleter(self.completer)
        self.input_1.setCompleter(self.completer)

        self.button_autocomplete_document = QtWidgets.QToolButton()
        helper.set_icon(self.button_autocomplete_document, "document")

    def create_layouts(self):
        """Create layouts."""
        super(LineInputDoubleColorspaces, self).create_layouts()

        self.layout.addWidget(self.button_autocomplete_document)

    def create_signals(self):
        """Create signals."""
        super(LineInputDoubleColorspaces, self).create_signals()

        self.button_autocomplete_document.clicked.connect(
            lambda: self.open_autocomplete_document()
        )

    def open_autocomplete_document(self):
        """Open the colorspaces.txt file for editing autocomplete values."""
        paths.reveal(colorspaces.get_user_colorspace_autocomplete_path())
