"""Show a simple dialog window where the user can input data."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui as QtWidgets
except ImportError:
    from PySide2 import QtCore
    from PySide2 import QtWidgets


def show(window, title, message, text):
    """Show a simple dialog window where the user can input data.

    Args:
        window (QtWidgets.QWidget): Parent window in order to keep the message
            box on top of the parent window.
        title (str): The title to show in the window.
        message (str): Message to display in the window.
        text (str): The start up text to display in the text input.

    Returns:
        str: The value that was entered into the dialog.

    """
    text, ok = QtWidgets.QInputDialog.getText(
        window, title, message, text=text
    )
    if ok:
        return text
